
.. py:currentmodule:: pythreejs

Frustum
====================================================

.. Use autoclass to fill any memebers not manually specified.
   This ensures it picks up any members in overridden classes.

.. autohastraits:: Frustum(p0=None, p1=None, p2=None, p3=None, p4=None, p5=None, )
    :members:
    :undoc-members:


    Inherits :py:class:`~pythreejs.ThreeWidget`.

    Three.js docs: https://threejs.org/docs/#api/math/Frustum


    .. py:attribute:: p0

        .. sourcecode:: python

            Instance(Plane, allow_none=True).tag(sync=True, **widget_serialization)

    .. py:attribute:: p1

        .. sourcecode:: python

            Instance(Plane, allow_none=True).tag(sync=True, **widget_serialization)

    .. py:attribute:: p2

        .. sourcecode:: python

            Instance(Plane, allow_none=True).tag(sync=True, **widget_serialization)

    .. py:attribute:: p3

        .. sourcecode:: python

            Instance(Plane, allow_none=True).tag(sync=True, **widget_serialization)

    .. py:attribute:: p4

        .. sourcecode:: python

            Instance(Plane, allow_none=True).tag(sync=True, **widget_serialization)

    .. py:attribute:: p5

        .. sourcecode:: python

            Instance(Plane, allow_none=True).tag(sync=True, **widget_serialization)

